#
# spec file for package brotli
#
# Copyright (c) 2017 Buschmann <buschmann23@opensuse.org>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#

%define _soname 1

Name:           brotli
Version:        1.0.2
Release:        lp151.3.3.1
License:        MIT
Summary:        Lossless Compression Algorithm
Url:            https://github.com/google/brotli
Group:          Productivity/Archiving/Compression
Source0:        https://github.com/google/brotli/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  cmake >= 2.8.6
BuildRequires:  gcc-c++
BuildRequires:  pkg-config
BuildRequires:  gzip

%description
This package contains the brotli command line utility to compress and decompress data with the brotli compression algorithm.

Brotli is a generic-purpose lossless compression algorithm that compresses data using a combination of a modern variant
of the LZ77 algorithm, Huffman coding and 2nd order context modeling, with a compression ratio comparable to the best
currently available general-purpose compression methods. It is similar in speed with deflate but offers more dense compression.

The specification of the Brotli Compressed Data Format is defined in RFC 7932.

%package -n libbrotlicommon%{_soname}
Summary:	Common Library for Brotli Compression
Group:		System/Libraries

%description -n libbrotlicommon%{_soname}
Common library for the Brotli general purpose lossless data compression algorithm.

%package -n libbrotlidec%{_soname}
Summary:        Library for Brotli Decompression
Group:          System/Libraries

%description -n libbrotlidec%{_soname}
Decompression library for the Brotli general purpose lossless data compression algorithm.

The specification of the Brotli Compressed Data Format is defined in RFC 7932.

%package -n libbrotlienc%{_soname}
Summary:        Library for Brotli Compression
Group:          System/Libraries

%description -n libbrotlienc%{_soname}
Compression library for the Brotli general purpose lossless data compression algorithm.

The specification of the Brotli Compressed Data Format is defined in RFC 7932.

%package -n libbrotli-devel
Summary:        Development and Header Files for Brotli Compression
Group:          Development/Libraries/C and C++
Requires:       libbrotlicommon%{_soname} = %{version}-%{release}
Requires:       libbrotlidec%{_soname} = %{version}-%{release}
Requires:       libbrotlienc%{_soname} = %{version}-%{release}
Provides:       libbrotlicommon-devel = %version-%release
Provides:       libbrotlidec-devel = %version-%release
Provides:       libbrotlienc-devel = %version-%release
Obsoletes:      libbrotlicommon-devel < %version-%release
Obsoletes:      libbrotlidec-devel < %version-%release
Obsoletes:      libbrotlienc-devel < %version-%release

%description -n libbrotli-devel
Development and headers files for (de)compressing data using the
Brotli general purpose lossless compression algorithm.

The specification of the Brotli Compressed Data Format is defined in RFC 7932.

%prep
%setup -q

%build
%cmake -DCMAKE_INSTALL_PREFIX:PATH="%{_prefix}" \
       -DCMAKE_INSTALL_LIBDIR:PATH="%{_libdir}" \
       -DBROTLI_DISABLE_TESTS:BOOL=off \
       -DCMAKE_SKIP_RPATH:BOOL=off
make %{?_smp_mflags}

%install
%cmake_install
rm %{buildroot}%{_libdir}/libbrotli*-static.a
%if 0%{?suse_version} > 1315
for i in docs/{brotli.1,decode.h.3,encode.h.3,types.h.3}; do
  install -D -t %{buildroot}%{_datadir}/man/man$(echo $i | sed 's:.*\.\([^\.]\)$:\1:') $i
done
%else
mkdir -p  %{buildroot}%{_datadir}/man/man{1,3}
for i in docs/{brotli.1,decode.h.3,encode.h.3,types.h.3}; do
  cp $i %{buildroot}%{_datadir}/man/man$(echo $i | sed 's:.*\.\([^\.]\)$:\1:')
done
%endif

%check
cd build
make test

%post -n libbrotlicommon%{_soname} -p /sbin/ldconfig
%postun -n libbrotlicommon%{_soname} -p /sbin/ldconfig

%post -n libbrotlidec%{_soname} -p /sbin/ldconfig
%postun -n libbrotlidec%{_soname} -p /sbin/ldconfig

%post -n libbrotlienc%{_soname} -p /sbin/ldconfig
%postun -n libbrotlienc%{_soname} -p /sbin/ldconfig

%files
%defattr(0644,root,root,755)
%doc LICENSE
%attr(755,root,root) /usr/bin/brotli
%{_mandir}/man1/brotli.1%{ext_man}

%files -n libbrotlicommon%{_soname}
%defattr(0644,root,root,755)
%{_libdir}/libbrotlicommon.so.*

%files -n libbrotlidec%{_soname}
%defattr(0644,root,root,755)
%{_libdir}/libbrotlidec.so.*

%files -n libbrotlienc%{_soname}
%defattr(0644,root,root,755)
%{_libdir}/libbrotlienc.so.*

%files -n libbrotli-devel
%defattr(0644,root,root,755)
%{_includedir}/brotli/
%{_libdir}/libbrotlicommon.so
%{_libdir}/libbrotlidec.so
%{_libdir}/libbrotlienc.so
%{_libdir}/pkgconfig/*.pc
%{_mandir}/man3/*.3%{ext_man}

%changelog
* Thu Jan 16 2020 Kristyna Streitova <kstreitova@suse.com>
- Add missing libbrotlicommon1 and libbrotlidec1 Requires to devel
  subpackage [bsc#1161104]
* Wed Jan  3 2018 jengelh@inai.de
- Merge devel subpackages as libbrotli-devel
* Sat Dec 30 2017 jengelh@inai.de
- Avoid shipping duplicate files.
  Avoid shipping README.md, this just contains the description -
  and build instructions.
- Drop duplicate Requires on -devel.
* Wed Dec 20 2017 pgajdos@suse.com
- build for SLE_12 and SLE_12_SP1
* Thu Nov 30 2017 buschmann23@opensuse.org
- update to Brotli 1.0.2
  + Major chnages
  * added Autotools build files
  * switched shared library version to libtool scheme
  + Minor changes
  * BrotliDictionary members are not const now
  * ZopfliNode distance could be up to 128MiB
  * fixed API documentation typos
  * total_out is always set by decoder
  * fixed BROTLI_ENSURE_CAPACITY macro; no-op in preprocessed output
  + Other changes
  * fixed scripts for oss-fuzz, test them with Travis
  * made Bazel JNI tests less messy
  * fixed linter warnings in JS decoder
  * fixed permissions of various files
  * added Bazel build to Appveyor matrix
  * added Sieve dictionary generator
* Tue Oct 24 2017 buschmann23@opensuse.org
- update to Brotli 1.0.1
  + updated README.md
  + fixed parallel exeuction of CMake "compatibility" tests
- update to Brotli 1.0.0
  + new CLI; bro -> brotli; + man page
  + remove "custom dictionary" support
  + add ability to side-load brotli RFC dictionary
  + add decoder API to avoid ringbuffer reallocation
  + PY streaming decompression support
  + PY wrapper accepts memview
- spec file changes
  + improve descriptions
  + add man pages
* Wed Sep 20 2017 buschmann23@opensuse.org
- spec file changes
  + improve package description
* Fri Jun 23 2017 buschmann23@opensuse.org
- update to Brotli 0.6.0
  + better compression on 1MiB+ files
  + update "common" API to make dictionary fetching more flexible
  + fix decoder bug #502
  + faster compression on mid-low quality levels
  + fix encoder q10-11 slowdown after long copy #468
  + introduce Brotli*TakeOutput API
- now build shared libraries and development files in the following
  new packages:
  + libbrotlicommon0_6_0
  + libbrotlicommon-devel
  + libbrotlidec0_6_0
  + libbrotlidec-devel
  + libbrotlienc0_6_0
  + libbrtolienc-devel
* Fri Mar 24 2017 buschmann23@opensuse.org
- initial package
